@@ -3,7 +3,7 @@ package Sort::Sub::pod_section_ala_perlancar;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-04-23'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.085'; # VERSION
+our $VERSION = '0.086'; # VERSION
 
 use 5.010001;
 use strict;
@@ -74,6 +74,10 @@ our $SORT_SPEC = [
     'CAVEATS',
     'SEE ALSO', 'ORIGINAL SEE ALSO',
 
+    # credits
+    'CREDITS', 'ORIGINAL CREDITS',
+    'THANKS', 'ORIGINAL THANKS',
+
     # author & copyright
     qr/^AUTHORS?/,
     qr/^.+'S AUTHORS?$/i, # in a forked module, i put the original module's AUTHOR in ORIGMODULE'S AUTHOR
@@ -117,7 +121,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.085 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-23.
+This document describes version 0.086 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-23.
 
 =head1 SYNOPSIS
 
